@@ -1,3 +1,5 @@
+from .auth import *
 from .projects import *
 from .data_donations import *
 from .questionnaire import *
+from .profile import *
