@@ -1,10 +1,12 @@
+from django.contrib import messages
+from django.contrib.messages.views import SuccessMessageMixin
 from django.http import Http404
 from django.urls import reverse
 from django.views.generic.edit import CreateView, UpdateView, DeleteView
 from django.views.generic.list import ListView
 
-from ddm.models import DonationBlueprint, ZippedBlueprint, DonationInstruction
-
+from ddm.forms import BlueprintEditForm
+from ddm.models import DonationBlueprint, ZippedBlueprint, DonationInstruction, DonationProject
 from ddm.views.project_admin import DdmAuthMixin
 
 
@@ -13,6 +15,7 @@ class BlueprintMixin:
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
         context.update({'project_pk': self.kwargs['project_pk']})
+        context.update({'project': DonationProject.objects.get(pk=self.kwargs['project_pk'])})
         return context
 
     def get_success_url(self):
@@ -37,25 +40,24 @@ class ProjectBlueprintList(DdmAuthMixin, BlueprintMixin, ListView):
         return queryset
 
 
-class BlueprintCreate(DdmAuthMixin, BlueprintMixin, CreateView):
+class BlueprintCreate(SuccessMessageMixin, DdmAuthMixin, BlueprintMixin, CreateView):
     """ View to create a new donation blueprint. """
     model = DonationBlueprint
     template_name = 'ddm/project_admin/blueprint/create.html'
     fields = ['name', 'exp_file_format', 'expected_fields', 'extracted_fields']
+    success_message = 'Blueprint was created successfully.'
 
     def form_valid(self, form):
         form.instance.project_id = self.kwargs['project_pk']
         return super().form_valid(form)
 
 
-class BlueprintEdit(DdmAuthMixin, BlueprintMixin, UpdateView):
+class BlueprintEdit(SuccessMessageMixin, DdmAuthMixin, BlueprintMixin, UpdateView):
     """ View to edit the details of an existing donation blueprint. """
     model = DonationBlueprint
     template_name = 'ddm/project_admin/blueprint/edit.html'
-    fields = [
-        'name', 'exp_file_format', 'expected_fields', 'extracted_fields',
-        'zip_blueprint', 'regex_path'
-    ]
+    form_class = BlueprintEditForm
+    success_message = 'Blueprint "%(name)s" was successfully updated.'
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
@@ -68,36 +70,49 @@ class BlueprintDelete(DdmAuthMixin, BlueprintMixin, DeleteView):
     """ View to delete an existing donation blueprint. """
     model = DonationBlueprint
     template_name = 'ddm/project_admin/blueprint/delete.html'
+    success_message = 'Blueprint "%s" was deleted.'
+
+    def delete(self, request, *args, **kwargs):
+        messages.success(self.request, self.success_message % self.get_object().name)
+        return super().delete(request, *args, **kwargs)
 
 
-class ZippedBlueprintCreate(DdmAuthMixin, BlueprintMixin, CreateView):
+class ZippedBlueprintCreate(SuccessMessageMixin, DdmAuthMixin, BlueprintMixin, CreateView):
     """ View to create a new zipped blueprint. """
     model = ZippedBlueprint
     template_name = 'ddm/project_admin/blueprint/create.html'
     fields = ['name']
+    success_message = 'Zip Blueprint was created successfully.'
 
     def form_valid(self, form):
         form.instance.project_id = self.kwargs['project_pk']
         return super().form_valid(form)
 
 
-class ZippedBlueprintEdit(DdmAuthMixin, BlueprintMixin, UpdateView):
+class ZippedBlueprintEdit(SuccessMessageMixin, DdmAuthMixin, BlueprintMixin, UpdateView):
     """ View to edit the details of an existing zipped blueprint. """
     model = ZippedBlueprint
     template_name = 'ddm/project_admin/blueprint/edit.html'
     fields = ['name']
+    success_message = 'Zip blueprint "%(name)s" was successfully updated.'
 
 
 class ZippedBlueprintDelete(DdmAuthMixin, BlueprintMixin, DeleteView):
     """ View to delete an existing zipped blueprint. """
     model = ZippedBlueprint
     template_name = 'ddm/project_admin/blueprint/delete.html'
+    success_message = 'Zip blueprint "%s" was deleted.'
+
+    def delete(self, request, *args, **kwargs):
+        messages.success(self.request, self.success_message % self.get_object().name)
+        return super().delete(request, *args, **kwargs)
 
 
 class InstructionMixin:
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
         context.update({'project_pk': self.kwargs['project_pk']})
+        context.update({'project': DonationProject.objects.get(pk=self.kwargs['project_pk'])})
         if self.kwargs['blueprint_type'] == 'blueprint':
             blueprint = DonationBlueprint.objects.get(id=self.kwargs['blueprint_pk'])
             blueprint_type = 'blueprint'
@@ -137,11 +152,12 @@ class InstructionOverview(DdmAuthMixin, InstructionMixin, ListView):
         return queryset
 
 
-class InstructionCreate(DdmAuthMixin, InstructionMixin, CreateView):
+class InstructionCreate(SuccessMessageMixin, DdmAuthMixin, InstructionMixin, CreateView):
     """ View to create an instruction page. """
     model = DonationInstruction
     template_name = 'ddm/project_admin/instructions/create.html'
     fields = ['text', 'index']
+    success_message = 'Instruction page was successfully created.'
 
     def get_blueprint(self):
         if self.kwargs['blueprint_type'] == 'blueprint':
@@ -169,17 +185,23 @@ class InstructionCreate(DdmAuthMixin, InstructionMixin, CreateView):
         return initial
 
 
-class InstructionEdit(DdmAuthMixin, InstructionMixin, UpdateView):
+class InstructionEdit(SuccessMessageMixin, DdmAuthMixin, InstructionMixin, UpdateView):
     """ View to edit an instruction page. """
     model = DonationInstruction
     template_name = 'ddm/project_admin/instructions/edit.html'
     fields = ['text', 'index']
+    success_message = 'Instruction page was successfully updated.'
 
 
 class InstructionDelete(DdmAuthMixin, InstructionMixin, DeleteView):
     """ View to delete an instruction page. """
     model = DonationInstruction
     template_name = 'ddm/project_admin/instructions/delete.html'
+    success_message = 'Instruction page was deleted.'
+
+    def delete(self, request, *args, **kwargs):
+        messages.success(self.request, self.success_message)
+        return super().delete(request, *args, **kwargs)
 
     def get_success_url(self):
         kwargs = {'project_pk': self.kwargs['project_pk'],
